@@ -6,7 +6,7 @@
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: localnetwork.cpp,v 1.6 2006/11/19 15:16:15 cepek Exp $
+ *  $Id: localnetwork.cpp,v 1.10 2007/06/26 15:04:11 cepek Exp $
  */
 
 
@@ -31,6 +31,7 @@
 #include <gnu_gama/xml/localnetwork.h>
 #include <gnu_gama/statan.h>
 #include <gnu_gama/gon2deg.h>
+#include <gnu_gama/version.h>
 
 using namespace std;
 using GNU_gama::LocalNetworkXML;
@@ -55,7 +56,7 @@ using GaMaLib::Zdiff;
 
 namespace 
 {
-  const char* const VERSION = "0.4a";
+  const char* const VERSION = "0.5";
 }
 
 
@@ -69,8 +70,15 @@ void LocalNetworkXML::write(std::ostream& out) const
   
   {
     {
+      using GNU_gama::GNU_gama_version;
+      using GNU_gama::GNU_gama_compiler;
+
       out << "\n<network-general-parameters\n";
     
+      out << "   gama-local-version=\""   << GNU_gama_version    << "\"\n";
+      out << "   gama-local-algorithm=\"" << netinfo->algorithm()<< "\"\n";
+      out << "   gama-local-compiler=\""  << GNU_gama_compiler   << "\"\n";
+
       out.setf(ios_base::fixed, ios_base::floatfield);
       out.precision(7);
       out << "   epoch=\""<< netinfo->epoch << "\"\n";
@@ -309,7 +317,7 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
   out << "\n<coordinates>\n";
 
   out.setf(ios_base::fixed, ios_base::floatfield);
-  out.precision(5);
+  out.precision(6);
   
   const GaMaLib::Vec& X = netinfo->solve();
   std::vector<Index> ind(netinfo->sum_unknowns() + 1);
@@ -460,6 +468,29 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
   
   out << "</cov-mat>\n";
   
+
+  out << "\n<!-- original indexes from the adjustment -->\n"
+      << "<original-index>\n";
+
+  for (PointData::const_iterator
+         i=netinfo->PD.begin(); i!=netinfo->PD.end(); ++i)
+    {
+      const LocalPoint& p = (*i).second;
+      if (!p.active_xy() && !p.active_z()) continue;
+      const bool bxy = p.active_xy() && p.index_x() != 0;
+      const bool bz  = p.active_z () && p.index_z() != 0;
+      if (bxy) out << "<ind>" << p.index_x() << "</ind>\n";
+      if (bxy) out << "<ind>" << p.index_y() << "</ind>\n";
+      if (bz ) out << "<ind>" << p.index_z() << "</ind>\n";
+    }
+
+  for (int i=1; i<=netinfo->sum_unknowns(); i++)
+    if (netinfo->unknown_type(i) == 'R')
+      {
+        out << "<ind>" << i << "</ind>\n";
+      }
+
+  out << "</original-index>\n";
   
   out << "\n</coordinates>\n";
 }
@@ -540,19 +571,22 @@ void LocalNetworkXML::observations(std::ostream& out) const
        ostringstream ostr;
        ostr.setf(ios_base::fixed, ios_base::floatfield);
 
+       const int linear  =  6;    // output precision 
+       const int angular =  7;    // output precision 
+
        if (Distance* d = dynamic_cast<Distance*>(pm))
          {
            out << "<" << (tag="distance") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = d->value();
-           ostr << " <obs>" <<m << "</obs>";
+           ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
            ostr << " <adj>" << m << "</adj>";
          }
        else if (Direction* s = dynamic_cast<Direction*>(pm))
          {
            out << "<" << (tag="direction") << ">";
-           ostr.precision(6);
+           ostr.precision(angular);
            double m = R2G*(s->value());
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/10000;
@@ -563,7 +597,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if ( (u = dynamic_cast<Angle*>(pm)) )
          {
            out << "<" << (tag="angle") << ">";
-           ostr.precision(6);
+           ostr.precision(angular);
            double m = R2G*(u->value());
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/10000;
@@ -574,7 +608,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (S_Distance* sd = dynamic_cast<S_Distance*>(pm))
          {
            out << "<" << (tag="slope-distance") << ">"; 
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = sd->value();
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
@@ -583,7 +617,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (Z_Angle* za = dynamic_cast<Z_Angle*>(pm))
          {
            out << "<" << (tag="zenith-angle") << ">";
-           ostr.precision(6);
+           ostr.precision(angular);
            double m = R2G*(za->value());
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/10000;
@@ -593,7 +627,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
          {
            xyz = true;
            out << "<" << (tag="coordinate-x") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = x->value();
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
@@ -603,7 +637,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
          {
            xyz = true;
            out << "<" << (tag="coordinate-y") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = y->value();
            ostr << " <obs>" << y_sign*m << "</obs>";
            m += v(i)/1000;
@@ -613,7 +647,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
          {
            xyz = true;
            out << "<" << (tag="coordinate-z") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = z->value();
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
@@ -622,7 +656,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (H_Diff* h = dynamic_cast<H_Diff*>(pm))
          {
            out << "<" << (tag="height-diff") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = h->value();
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
@@ -631,7 +665,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (Xdiff* dx = dynamic_cast<Xdiff*>(pm))
          {
            out << "<" << (tag="dx") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = dx->value();
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
@@ -640,7 +674,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (Ydiff* dy = dynamic_cast<Ydiff*>(pm))
          {
            out << "<" << (tag="dy") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = dy->value();
            ostr << " <obs>" << y_sign*m << "</obs>";
            m += v(i)/1000;
@@ -649,7 +683,7 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (Zdiff* dz = dynamic_cast<Zdiff*>(pm))
          {
            out << "<" << (tag="dz") << ">";
-           ostr.precision(5);
+           ostr.precision(linear);
            double m = dz->value();
            ostr << " <obs>" << m << "</obs>";
            m += v(i)/1000;
@@ -691,11 +725,13 @@ void LocalNetworkXML::observations(std::ostream& out) const
          ml *= scale;
        
        out << " <stdev>" << ml << "</stdev>\n";
-       // out.width(7);
-       // out << ml*kki;
 
+       // weight coefficient of the residual
+       double qrr = netinfo->wcoef_res(i);
+       out << "   <qrr>" << qrr << "</qrr>";
+              
        double f = netinfo->obs_control(i);
-       out << "   <f>" << f << "</f>";
+       out << " <f>" << f << "</f>";
               
        double sc=scale;
        if (f >= 0.1)
